
const glpbCommon = require('glpb-components-common');

require('./lp-fixed-right-button.scss');

const BaseComponent = glpbCommon.BaseComponent;

const $ = BaseComponent.$;
const eventCenter = glpbCommon.EventEmitter.eventCenter;

const LPFixedRightButton = BaseComponent.extend(
    {
        componentName : 'glpb_we_com_lp_fixed_right_button',
        componentNameZh : '固定右侧按钮',
        componentCategory : BaseComponent.CATEGORY.UI,
        platform : BaseComponent.PLATFORM.PC,
        canBeChildOfComponentName : function(){
            return true;
        }
    },
    {
        getDefaultStyle : function(){
            return {
                width : '86px',
                height: '85px',
            };
        },

        getDefaultData : function(){
            return {
                "scrollHeight_$$comment" : '滚动多少像素显示按钮',
                scrollHeight : 500,
                "imageSrc_$$comment" : '按钮图片',
                imageSrc: 'https://s0.renrendai.com/cms/5864b0d6a24d131067ef7956/PC-LP-picture/right-button_64.png',
                "bottom_$$comment" : '按钮距底部距离',
                bottom : '100px',

            };
        },

        init : function(){
            //是否已经绑定了组件自定义事件
            this.eventBinded = false;
            this.debounceTimer = null;
            this.myScroll = this.myScroll.bind( this );
        },

        myScroll : function() {
            clearTimeout(this.debounceTimer);
            let data = this.data || {};
            let scrollHeight = data.scrollHeight || 300;
            this.debounceTimer = setTimeout(function(){
                if ($(window).scrollTop() > scrollHeight){
                    $(".glpb-com-glpb_we_com_lp_fixed_right_button").fadeIn(1);
                } else {
                    $(".glpb-com-glpb_we_com_lp_fixed_right_button").fadeOut(1);
                }
            }, 100)
        },

        render : function(){
            let data = this.data || {};
            let style = this.style || {};
            const tpl = `<a class="fixed-right-icon"  style="bottom: ${data.bottom}" href="#lp-depository"></a>`;
            let cssClass = this.getBaseCssClass() + '  ';
            let cssStyle = this.translateStyle( this.style );
            let $el = $(tpl).addClass( cssClass ).css( cssStyle );
            this.$el = $el;
            this.$el.append(`<img src=${data.imageSrc} style="width: ${style.width}; height: ${style.height}"/>`);
            if(!this.isProductionMode()) {
                this.$el.css('display', 'block')
            }

        },

        bindComponentEvent : function(){
            if(this.isProductionMode() && ! this.eventBinded){
                $(window).on('scroll', this.myScroll);
                //点击发送注册组件聚焦事件
                this.$el.on('click', function () {
                    eventCenter.trigger('inputFocus');
                });
                this.eventBinded = true;
            }
        },

        componentWillUnmount : function(){
            if(this.eventBinded){
                $(window).off('scroll', this.myScroll);
            }
            this.$el = null;
            this.debounceTimer = null;
        },
    }
);


module.exports = LPFixedRightButton;