/**
 * LP页面顶部的header区域
 * Created by jess on 2016/9/22.
 */


const glpbCommon = require('glpb-components-common');

const DataManager = require('../../common/data-manager/data-manager.js');


require('./lp-header.scss');

const BaseComponent = glpbCommon.BaseComponent;

const $ = BaseComponent.$;

const utils = BaseComponent.utils;


const tpl = `<div><div class="glpb-content"></div></div>`;


const LandingPageHeader = BaseComponent.extend(
    {
        componentName : 'glpb_we_com_pc_lp_header',
        componentNameZh : 'PC-LP-header',
        componentCategory : BaseComponent.CATEGORY.UI,
        platform : BaseComponent.PLATFORM.PC,
        canBeChildOfComponentName : function(){
            return true;
        }
    },
    {
        getDefaultStyle : function(){
            return {
                background : {
                    backgroundColor : '#fff'
                },
                height : '70px',
                width : 'auto',
                padding : '0',
                margin : '0 auto'
            };
        },

        getDefaultData : function(){
            return {
                "logoImageURL_$$comment" : '公司logo图片的URL',
                logoImageURL : 'https://s0.renrendai.com/cms/5864b0d6a24d131067ef7956/PC-LP-picture/header-logo2.png',
                logoImageWidth : '226px',
                logoImageHeight : '25px',
                logoImageTop : '22px'
            };
        },

        init : function(){
            //当前Ajax请求的ID
            this.querySign = null;
            //是否已经绑定了组件自定义事件
            this.eventBinded = false;
        },

        render : function(){
            let currentComponentId = this.componentId;
            let data = this.data;

            let cssClass = this.getBaseCssClass() + '  ';
            let cssStyle = this.translateStyle( this.style );
            let $el = $(tpl).addClass( cssClass ).css( cssStyle );
            let $content = $('.glpb-content', $el);

            this.$el = $el;
            this.$content = $content;

            let html = `<a href="/"><img style="width:${data.logoImageWidth}; height:${data.logoImageHeight}; margin-top:${data.logoImageTop};" class="we-logo" src="${data.logoImageURL}" alt="logo" /></a>
<div class="we-contact">
<span class="user-abs">已有账号？<a href="/login">立即登录</a></span><img class="header-phone" src="https://s0.renrendai.com/cms/5864b0d6a24d131067ef7956/PC-LP-picture/lp-header-phone_05.png" alt=""/>
<span class="contact-us">95770</span>
</div>
`;

            $content.html( html );

            this.$logo = $content.find('.we-logo');
            this.$userAbs = $content.find('.user-abs');

        },

        bindComponentEvent : function(){
            let that = this;
            let data = this.data || {};
            if( this.isProductionMode() && ! this.eventBinded ){
                //正式环境才绑定事件, 并且Ajax请求
                let dataManager = DataManager.getInstance();

                let querySign = this.querySign = utils.generateQuerySign();

                dataManager.getUserInfo( )
                    .then( ( user ) => {

                        if( querySign !== that.querySign ){
                            return;
                        }

                        if( user ){
                            //当前用户已登录
                            let html = `您好，<a href="/user/account/p2p/index">${user.displayName}</a>`;
                            that.$userAbs.html( html );
                        }
                    })
                    .catch( (e) => {
                        console.warn( e );
                    });
            }
        },

        setData : function( data ){
            this.data = $.extend( {}, this.data, data );
            data = this.data;

            this.$logo.attr('src', data.logoImageURL).css({
                width : data.logoImageWidth,
                height : data.logoImageHeight,
                marginTop : data.logoImageTop
            });
        },

        componentWillUnmount : function(){
            this.querySign = null;
            this.$userAbs = null;
            this.$content = null;
        }


    }
);


module.exports = LandingPageHeader;

