
const glpbCommon = require('glpb-components-common');

require('./lp-hegui-group.scss');

const BaseComponent = glpbCommon.BaseComponent;

const $ = BaseComponent.$;

const LPHeguiGroup = BaseComponent.extend(
    {
        componentName : 'glpb_we_com_lp_hegui_group',
        componentNameZh : '合规介绍组',
        componentCategory : BaseComponent.CATEGORY.UI,
        platform : BaseComponent.PLATFORM.PC,
        canBeChildOfComponentName : function(){
            return true;
        }
    },
    {
        getDefaultStyle : function(){
            return {
                background: {
                    backgroundColor: '#ffffff'
                },
                margin: 'auto',
                width: '100%',
                padding: '36px 0 0',
            };
        },

        getDefaultData : function(){
            return {
                "title_$$comment" : '标题',
                title: '合规运营，我们不曾松懈',
                "cardList_$$comment" : '合规条目，必须成对出现',
                cardList : [{
                    image1: 'https://s0.renrendai.com/cms/5864b0d6a24d131067ef7956/PC-LP-picture/1.jpg',
                    title1: '银行资金存管',
                    content1: '出借人和借款人的资金直接通过银行存管账户进行操作，平台无法触碰资金，资金动态实时可查。平台提供专业的线上信贷及出借撮合服务，银行根据出借人和借款人双方真实交易信息划拨资金，用户资金与平台自有资金完全隔离。',
                    image2: 'https://s0.renrendai.com/cms/5864b0d6a24d131067ef7956/PC-LP-picture/2.jpg',
                    title2: '8年稳健运营',
                    content2: '自2010年成立以来，成立了专业资深的风控团队，构建了严格的风控体系；所属集团于2014年获得1.3亿美元A轮融资；2015年、2016年连续两年入围中国互联网百强企业排行榜；2017年入围胡润中国新金融50强。'
                }, {
                    image1: 'https://s0.renrendai.com/cms/5864b0d6a24d131067ef7956/PC-LP-picture/3.jpg',
                    title1: 'AAA级信用认证',
                    content1: '获得第三方评价机构iTrust互联网信用评价中心AAA级互联网信用认证。',
                    image2: 'https://s0.renrendai.com/cms/5864b0d6a24d131067ef7956/PC-LP-picture/4.jpg',
                    title2: '合规排名前列',
                    content2: '根据网贷之家2018年9月网贷平台发展指数评级数据，合规得分96.5，排名领先。'
                }],

            };
        },

        init : function(){
            //是否已经绑定了组件自定义事件
            this.eventBinded = false;
        },

        render : function(){
            let data = this.data || {};
            const tpl = `<div class="product-credit-group">
                <div class="title">
                    ${data.title}
                </div>
                <div class="line"></div>
                <div id="credit-content" class="credit-content"></div>
            </div>`;

            let cssClass = this.getBaseCssClass() + '  ';
            let cssStyle = this.translateStyle( this.style );
            let $el = $(tpl).addClass( cssClass ).css( cssStyle );
            let $content = $('#credit-content', $el);
            this.$content = $content;
            this.$el = $el;
            
            let cardList = data.cardList || [];
            if(!cardList || cardList.length < 1) {
                return 
            }
            cardList.forEach((item) => {
                let html = this._renderItem(item)
                this.$content.append(html);
            })
        },

        _renderItem : function( item ){
            return `<div class="credit">
                        <div class="credit-item">
                            <img class="credit-image" src=${item.image1} alt="">
                            <div class="credit-title">${item.title1}</div>
                            <div class="credit-description">${item.content1}</div>
                        </div>
                        <div class="credit-item">
                            <img class="credit-image" src=${item.image2} alt="">
                            <div class="credit-title">${item.title2}</div>
                            <div class="credit-description">${item.content2}</div>
                        </div>
                        <div class="credit-line"></div>
                    </div>
            `;
        },

        bindComponentEvent : function(){
            
        },

        componentWillUnmount : function(){
            this.$el = null;
        },
    }
);


module.exports = LPHeguiGroup;