
const glpbCommon = require('glpb-components-common');

const serviceFactory = require('../../service/service-factory.js');

require('./lp-product-group.scss');

const BaseComponent = glpbCommon.BaseComponent;
const eventCenter = glpbCommon.EventEmitter.eventCenter;
const $ = BaseComponent.$;

const utils = BaseComponent.utils;

const uPlanService = serviceFactory.getService('uPlan');
const lpService = serviceFactory.getService('lp');

const ProductGroup = BaseComponent.extend(
    {
        componentName : 'glpb_we_com_pc_lp_product_group',
        componentNameZh : '（即将废弃）PC产品组',
        componentCategory : BaseComponent.CATEGORY.UI,
        platform : BaseComponent.PLATFORM.PC,
        canBeChildOfComponentName : function(){
            return true;
        }
    },
    {
        getDefaultStyle : function(){
            return {
                background: {
                    backgroundColor: '#f6f8fc',
                },
                width: '100%',
                height: '430px',
                padding: '36px 0 47px',
            };
        },

        getDefaultData : function(){
            return {
                "title_$$comment" : "大标题",
                title: '明星产品',
                "productList_$$comment" : "产品卡顺序(默认['新手', '优选', 'U享']，去掉即不显示这一项)",
                productList : ['新手', '优选', 'U享'],
                "newComerTitle_$$comment" : '新手专享标题',
                newComerTitle : 'U享服务-新手专享',
                "newComerSubTitle_$$comment" : '新手专享标题下方小字',
                newComerSubTitle : '1个月服务期限',
                "uXuanTitle_$$comment" : '优选标题',
                premiumTitle : '优选服务',
                "uXuanSubTitle_$$comment" : '优选标题下方小字',
                premiumSubTitle : '12个月服务期限',
                "uPlanTitle_$$comment" : 'U享标题',
                uPlanTitle : 'U享服务',
                "uPlanSubTitle_$$comment" : 'U享标题下方小字',
                uPlanSubTitle : '12~36个月服务期限',
                "uPlanParamsList_$$comment" : "U享产品范围(支持1~2个参数),可选参数有'A-1','A-3','B-6','C-12','C-24','C-36'",
                uPlanParamsList : ['C-12', 'C-36'],
                "extraTitle_$$comment" : '扣费后年利率',
                extraTitle : '扣费后年利率',
            };
        },

        init : function(){
            //当前Ajax请求的ID
            this.querySign = null;
            //是否已经绑定了组件自定义事件
            this.eventBinded = false;
            //交易所列表对应的详细数据
            this.listDetailData = null;
            this.newComerHtml = '';
            this.premiumHtml = '';
            this.uPlanHtml = '';
        },

        render : function(){
            let data = this.data || {};
            const tpl = `<div>
                <div class="product-card-group">
                    <div class="title">${data.title}</div>
                    <div class="line"></div>
                    <div id="product-card-group-content" class="card"></div>
                </div>
            </div>`;
            let cssClass = this.getBaseCssClass() + '  ';
            let cssStyle = this.translateStyle( this.style );
            let $el = $(tpl).addClass( cssClass ).css( cssStyle );
            let $content = $('#product-card-group-content', $el);

            this.$el = $el;
            this.$content = $content;
            if( ! this.isProductionMode() ){
                //编辑模式, 显示一个图片占位
                $(`<img class="editor-place-holder-img" src="https://s0.renrendai.com/cms/5864b3f0c5ee7210913f6796/0207xiaoshuo/copy.png" title="产品组占位图片(非真实数据)" />`).appendTo( $content );
            }
        },

        bindComponentEvent : function(){
            let that = this;
            let data = this.data || {};
            let productList = data.productList;
            let uPlanParamsList = data.uPlanParamsList || [];
            this.querySign = utils.generateQuerySign();
            let reqData = {
                type : 'A-1'
            };

            //  获取U计划新客专享
            if(that.isProductionMode() && ! that.eventBinded) {
                const newComer = lpService.getNewer( reqData )
                    .then( ( reqResult ) => {
                        if( reqResult.requestStatus === lpService.STATUS.SUCCESS ){
                            let result = reqResult.data;
                            if( result.status === 0 ){
                                that.newComerHtml = that.setNewerOwnData( result.data.list );
                                return;
                            }
                            return Promise.reject(new Error(result.message));
                        }
                        return Promise.reject( new Error('获取新手专享数据异常!'));
                    })
                    .catch( (e) => {
                        alert(e.message);
                    });

                const premium = uPlanService.getUplanPremium()
                    .then( (reqResult) =>{
                        if( reqResult.requestStatus === uPlanService.STATUS.SUCCESS ){
                            let result = reqResult.data;
                            if( result.status === 0 ){
                                that.premiumHtml = that.setPremiumData( result.data.list );
                                return;
                            }
                            return Promise.reject( new Error(result.message) );
                        }
                        return Promise.reject( new Error('获取优选数据异常!') );
                    })
                    .catch( (e) => {
                        alert( e.message );
                    });

                let uPlan = Promise.resolve('');
                if( uPlanParamsList.length > 0 ){
                    this.querySign = utils.generateQuerySign();
                    let reqData = {
                        needUPlanList : uPlanParamsList.join(",")
                    };
    
                    uPlan = uPlanService.getUPlanListByCondition( reqData )
                        .then( ( reqResult ) => {
                            if( reqResult.requestStatus === uPlanService.STATUS.SUCCESS ){
                                let result = reqResult.data;
                                if( result.status === 0 ){
                                    that.uPlanHtml = that.setUPlanData( result.data.list );
                                    return;
                                }
                                return Promise.reject(new Error(result.message));
                            }
                            return Promise.reject( new Error('获取U享数据异常!'));
                        })
                        .catch( (e) => {
                            alert(e.message);
                        });
                }
                
                Promise.all([newComer, uPlan, premium])
                    .then(function() {
                        let html = ''
                        productList.forEach((item) => {
                            if(item === '新手') {
                                html += that.newComerHtml;
                            }
                            if(item === '优选') {
                                html += that.premiumHtml;
                            }
                            if(item === 'U享') {
                                html += that.uPlanHtml;
                            }
                        });
                        that.$content.append( html );
                        $('.card-button', that.$content).on('click', function(){
                            eventCenter.trigger('inputFocus');
                        })
                    }).catch(function() {
                        console.log('获取产品卡数据异常')
                    }) 
            }
            
        },

        componentWillUnmount : function(){
            this.$content = null;
        },

        
        setUPlanData : function( list ){
            list = list || [];
            if( ! list || list.length < 1 ){
                return '';
            }

            let html = this._renderUPlanItem( list[0], list[list.length - 1] );
            return html || '';
        },

        setNewerOwnData : function( list ){
            list = list || [];
            if( ! list || list.length < 1 ){
                return '';
            }

            let html = this._renderNewnerOwnItem( list[0] );

            return html || '';
        },

        setPremiumData : function(list){
            list = list || []
            if( !list && list.length < 1 ){
                return '';
            }
            let html = this._renderPremium(list[0]);
           
            return html || '';
        },

        _renderPremium : function(obj){
            let data = this.data || {};
            let rate = Number(obj.expectedYearRate).toFixed(1);
            let premiumTitle = data.premiumTitle || '';
            let premiumSubTitle = data.premiumSubTitle || '';
            let extraTitle = data.extraTitle || '扣费后年利率'

            return `<div class="card-item">
                <div class="card-title">${premiumTitle}</div>
                <div class="card-time">${premiumSubTitle}</div>
                <div class="card-rate">${rate}<span class="card-percent">%</span></div>
                <div class="card-description">${extraTitle}</div>
                <a class="card-button" href="#lp-depository">授权出借</a>
            </div>`;
        },

        _renderNewnerOwnItem : function( obj ){
            let data = this.data || {};
            let rate = Number(obj.expectedYearRate).toFixed(1);
            let newComerTitle = data.newComerTitle || '';
            let newComerSubTitle = data.newComerSubTitle || '';
            let extraTitle = data.extraTitle || '扣费后年利率'

            return `<div class="card-item">
                        <div class="card-title">${newComerTitle}</div>
                        <div class="card-time">${newComerSubTitle}</div>
                        <div class="card-rate">${rate}<span class="card-percent">%</span></div>
                        <div class="card-description">${extraTitle}</div>
                        <a class="card-button" href="#lp-depository">授权出借</a>
                    </div>
            `;
        },

        _renderUPlanItem : function( minItem, maxItem ){
            if(!minItem) {
                return ''
            }
            let data = this.data || {};
            let uPlanTitle = data.uPlanTitle || '';
            let uPlanSubTitle = data.uPlanSubTitle || '';
            let extraTitle = data.extraTitle || '扣费后年利率'
            if(maxItem) {
                let minRate = Number(minItem.expectedYearRate).toFixed(1);
                let maxRate = Number(maxItem.expectedYearRate).toFixed(1);
                return `<div class="card-item">
                            <div class="card-title">${uPlanTitle}</div>
                            <div class="card-time">${uPlanSubTitle}</div>
                            <div class="card-rate">${minRate}<span class="card-percent">%</span><span class="card-percent">~</span>${maxRate}<span class="card-percent">%</span></div>
                            <div class="card-description">${extraTitle}</div>
                            <a class="card-button" href="#lp-depository">授权出借</a>
                        </div>`
            } else {
                let minRate = Number(minItem.expectedYearRate).toFixed(1);
                return `
                <div class="card-item">
                    <div class="card-title">${uPlanTitle}</div>
                    <div class="card-time">${uPlanSubTitle}</div>
                    <div class="card-rate">${minRate}<span class="card-percent">%</span></div>
                    <div class="card-description">${extraTitle}</div>
                    <a class="card-button" href="#lp-depository">授权出借</a>
                </div>`
            }
        }
    }
);


module.exports = ProductGroup;