/**
 * LP页面 注册框 
 * Created by jess on 2016/9/22.
 */



const glpbCommon = require('glpb-components-common');

const DataManager = require('../../common/data-manager/data-manager.js');

const GForm = require('../../common/form/form.js');


require('./lp-register-box.scss');

const BaseComponent = glpbCommon.BaseComponent;

const $ = BaseComponent.$;

const rrdValidate = glpbCommon.rrdValidate;

const utils = BaseComponent.utils;

const Cookies = glpbCommon.Cookies;

const TextInput = GForm.TextInput;
const RandCodeImage = GForm.RandCodeImage;
const Checkbox = GForm.Checkbox;


const tpl = __inline('./lp-register-box.tpl');

const SECONDS = 60;
let remainSeconds = 0;

const LandingPageHeader = BaseComponent.extend(
    {
        componentName : 'glpb_we_com_pc_lp_register_box',
        componentNameZh : 'PC-LP-注册框',
        componentCategory : BaseComponent.CATEGORY.UI,
        platform : BaseComponent.PLATFORM.PC,
        canBeChildOfComponentName : function(){
            return true;
        }
    },
    {
        getDefaultStyle : function(){
            return {
                minHeight : '354px',
                width : '350px',
                height: 'auto',
                padding : '0',
                margin : '0 auto'
            };
        },

        getDefaultData : function(){
            return {
                "logoImageURL_$$comment" : '公司logo图片的URL',
                logoImageURL : 'http://www.we.com/static/loadingpage/img/logo-new-two_d0e7702.png',
                promotion : '',
                inviteCode : '',
                type : '',
                intention : 'LENDER',
                submitText : '注册领红包',
                submitBtnTheme: 'orange',
                boxBackgroundColor : '#fff',
                boxBackgroundOpacity : '1'
            };
        },

        init : function(){
            //当前Ajax请求的ID
            this.querySign = null;
            //是否已经绑定了组件自定义事件
            this.eventBinded = false;

            this.handleStep1Submit = this.handleStep1Submit.bind( this );

            //获取promotion和inviteCode
            let searchConf = utils.getSearchConf();

            let data = this.data;

            if( ! data.promotion ){
                let promotion = searchConf.promotion || searchConf.utmSource || '';

                if( ! promotion || ! /[-a-zA-Z0-9?=_/]{1,128}/.test(promotion) ){
                    //从 promotion_source  这个cookie中读取
                    promotion = Cookies.get('promotion_source', { path: '/' });
                }

                data.promotion = promotion || '';
            }

            if( data.promotion ){
                //写入cookie中
                Cookies.set('promotion_source', data.promotion, { path: '/', expires : 365 });
            }

            if( ! data.inviteCode ){
                data.inviteCode = searchConf.inviteCode || '';
            }
        },

        render : function(){
            let currentComponentId = this.componentId;
            let data = this.data;
            let cssClass = this.getBaseCssClass() + '  ';
            let cssStyle = this.translateStyle( this.style );
            let $el = $(tpl).addClass( cssClass ).css( cssStyle );
            let $content = $('.glpb-content', $el);

            this.$el = $el;
            this.$boxBg = $el.find('.reg-box-bg');
            this.$content = $content;
            this.$stepContainer = $content.find('.step-container');
            this.$step1 = this.$stepContainer.find('.step-1');
            this.$step2 = this.$stepContainer.find('.step-2');


            this.renderStep1();

            this.updateForm();

            this.sendPhoneCode();

        },

        renderStep1 : function(){

            let form = new GForm({
                method : 'post',
                action : '/rrdRegist!beforeRegist.action',
                onSubmit : this.handleStep1Submit
            });

            form.render();

            this.form = form;

            //添加各个输入框子项
            let errorClass = 'validate-error-con';


            //手机号
            let phoneProps = {
                name : 'username',
                id : 'phone',
                className : 'mobile-phone-con register-item-con',
                errorClass : errorClass,
                placeholder : '输入手机号码',
                validate : {
                    blur : [ 'required', 'isMobile', 'isMobileAvailable' ]
                }
            };

            //密码
            let passwrodProps = {
                type : 'password',
                name : 'password',
                id : 'password',
                className : 'password-con register-item-con',
                errorClass : errorClass,
                placeholder : '设置登录密码',
                validate : {
                    blur : [ 'required',
                        'isPassWord',
                        'isPassNotAllNum',
                        'isPassNotRepeat',
                        {
                            fn : 'minlength',
                            message : 'minPswLength',
                            args : 6
                        },
                        {
                            fn : 'maxlength',
                            message : 'maxPswLength',
                            args : 16
                        }
                    ]
                }
            };

            //手机验证码
            let phoneCodeProps = {
                name : 'mobileCode',
                id : 'phoneCode',
                className : 'phone-code-input ',
                errorClass : errorClass,
                placeholder : '输入验证码',
                validate : {
                    blur : [ 'required' ]
                }
            };

            //验证码
            let randCodeProps = {
                name : 'randCode',
                id : 'randCode',
                className : 'rand-code-con ',
                errorClass : errorClass,
                placeholder : '验证码',
                validate : {
                    blur : [ 'required',
                        {
                            fn : 'isLengthEqual',
                            message : 'phoneCodeMsgLength',
                            args : 4
                        }
                    ]
                }
            };



            //验证码图片组件
            let codeImageProps = {
                className : 'code-image-con'
            };

            //单选框
            let checkboxProps = {
                name : 'agree',
                label : '我已阅读并同意',
                className : 'register-agree-con',
                errorClass : errorClass,
                checked : true,
                validate : {
                    change : [ {
                        fn : 'isChecked',
                        message : 'agree'
                    } ]
                },
                children : '<a href="/agreement/rv_webservice.html" target="_blank">《人人贷WE理财注册服务协议》</a>'
            };

            let $formElement = form.$getElement();


            //手机号
            let mobileInput = new TextInput( phoneProps );
            mobileInput.render();
            form.addInputItem( mobileInput );
            $formElement.append( mobileInput.$getElement() );

            //手机验证码
            let phoneCodeInput = new TextInput( phoneCodeProps );
            phoneCodeInput.render();
            form.addInputItem( phoneCodeInput );

            //获取验证码按钮
            let $mobileCodeWrap = $(`<div class="phone-code-item-con phone-code-wrap fn-clear clearfix"></div>`);
            let $codeBtn = $(`<div id="count-down-wrap" class="count-down-wrap">获取验证码</div>`);
            $mobileCodeWrap.append(phoneCodeInput.$getElement());
            $mobileCodeWrap.append($codeBtn);
            form.addElementItem( $mobileCodeWrap );

            //密码
            let passInput = new TextInput( passwrodProps );
            passInput.render();
            form.addInputItem( passInput );
            $formElement.append( passInput.$getElement() );

            /*//验证码输入框
            let randCodeInput = new TextInput( randCodeProps );
            randCodeInput.render();
            form.addInputItem( randCodeInput );
            
            //验证码图片
            let randCodeImg = new RandCodeImage( codeImageProps );
            randCodeImg.render();
            form.addComponentItem( randCodeImg );

            let $randCon = $('<div class="register-item-con phone-code-wrap fn-clear clearfix"></div>');
            
            $randCon.append( randCodeInput.$getElement() );
            $randCon.append( randCodeImg.$getElement() );

            form.addElementItem( $randCon );*/

            //注册协议单选框
            let checkbox = new Checkbox( checkboxProps );
            checkbox.render();
            form.addInputItem( checkbox );
            let $itemBlock = $('<div class="register-item-con agreement-wrap"></div>');
            $itemBlock.append( checkbox.$getElement() );

            form.addElementItem( $itemBlock );

            //提交按钮和其他隐藏域
            let data = this.data;
            let submitText = data.submitText || '注册领红包';
            
            let html = `<div><input type="hidden" name="lpjumptoreg" value="1" />
                    <input type="hidden" name="type" value="${data.type}" />
                    <input type="hidden" name="intention" value="${data.intention}" />
                    <input type="hidden" name="promotion" value="${data.promotion}" />
                    <input type="hidden" name="inviteCode" value="${data.inviteCode}" />
                    <input type="submit" class="submit-btn" value="${submitText}" />
                    <div class="submit-error-info"></div></div>`;

            let $remain = $(html);

            this.$submitBtn = $remain.find('.submit-btn');
            this.$countDown = $formElement.find('#count-down-wrap');

            form.addElementItem( $remain );

            this.$step1.append( form.$getElement() );

        },

        bindComponentEvent : function(){
            let that = this;
            let data = this.data || {};

            this.form.bindEvent();
            if( this.isProductionMode() && ! this.eventBinded ){
                //正式环境才绑定事件, 并且Ajax请求
 
                let querySign = this.querySign = utils.generateQuerySign();

            }
        },

        //图形验证码校验
        isRankCode: function() {

            let $formElement = this.form.$getElement();
            let $rankCodeShow = $formElement.find('.rank-code-wrap:visible');

            var isRankOk = false;

            if ($rankCodeShow.length > 0) {

                var randCode = $randCode.val() || "";

                if (randCode.length == 0) {
                    mess = "不能为空";
                    ////
                } else if (randCode.length == 4) {
                    ////
                    isRankOk = true;
                } else {
                    mess = "请输入4位验证码";
                    ////
                }
            } else {
                isRankOk = true;
            }

            return isRankOk;
        },

        sendPhoneCode: function(){
            let that = this;
            let $formElement = this.form.$getElement();
            let $countDown = this.$countDown;
            let $phone = $formElement.find('#phone');
            let $randCode = $formElement.find('#randCode');
            let $submitErroInfo = $formElement.find('.submit-error-info');
            let validateProvider = rrdValidate.validate;

            $countDown.on('click', function () {

                if (remainSeconds > 0) {
                    return;
                }

                var mobileNum = $phone.val();
                var randCode = $randCode.val() || "";

                //发送验证码前验证手机号
                if (!(validateProvider.isMobile(mobileNum) && validateProvider.isMobileAvailable(mobileNum))) {
                    return;
                }

                if (!that.isRankCode()) {
                    return;
                }

                //异步发送手机验证码
                var url = '/sendPhoneCode.action';
                var data = {
                    checkCode: 'regNew',
                    phone: mobileNum,
                    randomCode: randCode
                };

                $.post(url, data).done(function (res) {

                    if (res.status == '3230') {
                        //显示验证码
                        ////$loginHeight.css("height", "420px");
                        ////$("#form-phone").css("top", "37px!important");
                        ////$rankCodeWrap.show();
                        ////$img_clickable.trigger("click");
                    } else if (res.status == '3240') {
                        $img_clickable.trigger("click");
                        mess = "验证码不正确";
                        ////
                    } else {
                        that.resetCountdown(); //发送验证码
                        sendTimes++;
                    }
                }).fail(function () {
                    ////$img_clickable.trigger("click");
                    $submitErroInfo.text('服务器异常,请稍后再试');
                });
            });
        },

        sendFresh: function(){
            let that = this;
            let $countDown = this.$countDown;
            //重新发送刷新验证码
            $(".count-down-fresh").on('click', function () {
                $(".count-down-fresh").unbind("click");
                ////$img_clickable.trigger("click");
                $countDown.removeClass("count-down-fresh").addClass("count-down-wrap");
                that.sendPhoneCode();
            });
        },
        //重新发送手机验证的倒计时
        resetCountdown: function() {
            let that = this;
            let $countDown = this.$countDown;

            clearTimeout(timer);

            remainSeconds = SECONDS;

            $countDown.text('重新发送(' + remainSeconds + ')');

            $countDown.addClass("submit-gary").removeClass("submit-orange");

            function update() {
                remainSeconds--;
                if (remainSeconds < 1) {
                    if (sendTimes > 0) {
                        $countDown.removeClass("count-down-wrap").addClass("count-down-fresh");
                        $countDownClass.unbind('click');
                        that.sendFresh();
                    }
                    $countDown.text('重新发送');
                    $countDown.addClass("submit-orange").removeClass("j-btn-gary");
                } else {
                    $countDown.text('重新发送(' + remainSeconds + ')');
                    timer = setTimeout(update, 1000);
                }
            }

            timer = setTimeout(update, 1000);
        },

        handleStep1Submit : function(){},

        setData : function(data){
            this.data = $.extend( this.data, data );

            this.updateForm();
        },

        updateForm : function(){
            let data = this.data;

            this.$boxBg.css({
                backgroundColor : data.boxBackgroundColor,
                opacity : data.boxBackgroundOpacity
            });

            this.$submitBtn.val( data.submitText || '注册领红包' );

            let submitBtnClass = '';

            switch( data.submitBtnTheme ){
                case 'orange':
                    submitBtnClass = 'submit-orange';
                    break;
                case 'blue':
                    submitBtnClass = 'submit-blue';
                    break;
                default:
                    submitBtnClass = 'submit-orange';
                    break;
            }

            this.$submitBtn.attr('class', 'submit-btn ' + submitBtnClass );
            this.$countDown.attr('class', 'count-down-wrap ' + submitBtnClass );
        },

        componentWillUnmount : function(){
            this.form.destroy();
            this.form = null;
            this.querySign = null;
            this.$content = null;
        }


    }
);


module.exports = LandingPageHeader;

