
const glpbCommon = require('glpb-components-common');

const serviceFactory = require('../../service/service-factory.js');

require('./new-product-group.scss');

const BaseComponent = glpbCommon.BaseComponent;
const eventCenter = glpbCommon.EventEmitter.eventCenter;
const $ = BaseComponent.$;

const utils = BaseComponent.utils;

const uPlanService = serviceFactory.getService('uPlan');


const ProductGroup = BaseComponent.extend(
    {
        componentName : 'glpb_we_com_pc_new_product_group',
        componentNameZh : '新版PC产品组',
        componentCategory : BaseComponent.CATEGORY.UI,
        platform : BaseComponent.PLATFORM.PC,
        canBeChildOfComponentName : function(){
            return true;
        }
    },
    {
        getDefaultStyle : function(){
            return {
                background: {
                    backgroundColor: '#f6f8fc',
                },
                width: '100%',
                height: '430px',
                padding: '36px 0 47px',
            };
        },

        getDefaultData : function(){
            return {
                "title_$$comment" : "组件大标题",
                title: '明星产品',
                "productList_$$comment" : [{
                    type:'三种选择（T1：新手专享，T2：优选，T3：优享）',
                    mainTitle: '产品卡主标题',
                    subTitle: '产品卡副标题',
                    extraTitle: '扣费后年利率文案',
                    btnText: '按钮文案',
                    background: '产品卡背景色',
                    backgroundImage: '产品卡背景图（和背景色二者配置其一即可）',
                    timeRange: "U享产品范围(注意：支持1~2个参数，只有在type为T3的时候添加该字段),可选参数有'A-1','A-3','B-6','C-12','C-24','C-36'(月份从小到大)"
                }],
                "productList":[
                    {
                        type: 'T1',
                        mainTitle: 'U享服务-新手专享',
                        subTitle: '1个月服务期限',
                        extraTitle: '扣费后年利率',
                        btnText: '授权出借',
                        background: '#fff',
                        backgroundImage: '',
                    },
                    {
                        type: 'T2',
                        mainTitle: '优选服务',
                        subTitle: '12个月服务期限',
                        extraTitle: '扣费后年利率',
                        btnText: '授权出借',
                        background: '#fff',
                        backgroundImage: '',
                    },
                    {
                        type: 'T3',
                        mainTitle: 'U享服务24-36个月',
                        subTitle: '12个月服务期限',
                        extraTitle: '扣费后年利率',
                        btnText: '授权出借',
                        timeRange: ['C-24', 'C-36'],
                        background: '#fff',
                        backgroundImage: 'https://s0.renrendai.com/cube/201905%205.8%E5%8F%91%E8%B4%A2%E8%8A%82/APP/%E4%BC%98%E6%83%A0%E5%88%B8%E8%83%8C%E6%99%AF.png',
                    },

                ],
            };
        },

        init : function(){
            //当前Ajax请求的ID
            this.querySign = null;
            //是否已经绑定了组件自定义事件
            this.eventBinded = false;
        },

        render : function(){
            const data = this.data || {};
            const title = data.title || '明星产品';
            const tpl = `<div>
                <div class="product-card-group">
                    <div class="title">${title}</div>
                    <div class="line"></div>
                    <div id="product-card-group-content" class="card"></div>
                </div>
            </div>`;
            let cssClass = this.getBaseCssClass() + '  ';
            let cssStyle = this.translateStyle( this.style );
            let $el = $(tpl).addClass( cssClass ).css( cssStyle );
            let $content = $('#product-card-group-content', $el);

            this.$el = $el;
            this.$content = $content;
            if( ! this.isProductionMode() ){
                //编辑模式, 显示一个图片占位
                $(`<img class="editor-place-holder-img" src="https://s0.renrendai.com/cms/5864b3f0c5ee7210913f6796/0207xiaoshuo/copy.png" title="U计划列表占位图片(非真实数据)" />`).appendTo( $content );
            }
        },

        bindComponentEvent : function(){
            const that = this;
            const data = this.data || {};
            const productList = data.productList || [];
            
            if(that.isProductionMode() && !that.eventBinded) {
                const list = productList.map(function (e) {
                    const cardObj = {
                        type: e.type
                    }
                    if(e.type === 'T3')  cardObj.timeRange = e.timeRange;
                    return cardObj;
                });
                this.querySign = utils.generateQuerySign();
                uPlanService.getProductCardRatio({list:JSON.stringify(list)}).then(result=>{
                    if( result.requestStatus === uPlanService.STATUS.SUCCESS ){
                        const res = result.data || {};
                        if (res.status === 0) {
                            const htmlStr = that._renderProductCard(res.data);
                            that.$content.append( htmlStr );
                            $('.card-button', that.$content).on('click', function(){
                                eventCenter.trigger('inputFocus');
                            })
                            return;
                        }
                        return Promise.reject(new Error(res.message));

                    }
                    return Promise.reject( new Error('获取产品卡相关数据异常!') );
                }).catch(err => {
                    console.log(err)
                })
                
            }
            
        },

        componentWillUnmount : function(){
            this.$content = null;
        },

        _renderProductCard : function(ratioArr = []){
            const data = this.data || {};
            const productList = data.productList || [];
            let htmlStr = '';
            productList.forEach((val, index) => {
                let ratio = ratioArr[index] && ratioArr[index].ratio;
                if(Array.isArray(ratio)){
                    if(ratio.length === 2){
                        ratio = `${ratio[0]}<span class="card-percent">%~</span>${ratio[1]}<span class="card-percent">%</span>`
                    }else{
                        ratio = `${ratio[0]}<span class="card-percent">%</span>`
                    }
                }else{
                    ratio = `${ratio}<span class="card-percent">%</span>`
                }
                const bg = val.backgroundImage ? `background-image:url('${val.backgroundImage}')` : `background:${val.background}`;
                htmlStr += `<div class="card-item" style="${bg}">
                    <div class="card-title">${val.mainTitle}</div>
                    <div class="card-time">${val.subTitle}</div>
                    <div class="card-rate">${ratio}</div>
                    <div class="card-description">${val.extraTitle || '扣费后年利率'}</div>
                    <a class="card-button" href="#lp-depository">${val.btnText || '授权出借'}</a>
                </div>`
            })
            return htmlStr
        }
    }
);


module.exports = ProductGroup;