/*
 * 新手专享-条形样式
 * 王浩
 */

const moment = require('moment');

const numeral = require('numeral');

const glpbCommon = require('glpb-components-common');

const serviceFactory = require('../../service/service-factory.js');

require('./newer.scss');

const BaseComponent = glpbCommon.BaseComponent;

const $ = BaseComponent.$;

const utils = BaseComponent.utils;

const lpService = serviceFactory.getService('lp');

const tpl = `<div><ul class="glpb-newer-own-list"></ul></div>`;

const editorPlaceHolderImage = '//www.we.com/cms/5864b3f0c5ee7210913f6796/register/place-holder-img/newer-plan-place-holder-img.png';

const NewerOwnItemList = BaseComponent.extend(
    {
        componentName : 'glpb_we_com_pc_newer-own_item_list',
        componentNameZh : '新手专享-条形',
        componentCategory : BaseComponent.CATEGORY.UI,
        platform : BaseComponent.PLATFORM.PC,
        canBeChildOfComponentName : function(){
            return true;
        }
    },
    {
        getDefaultStyle : function(){
            return {
                background : {
                    backgroundColor : '#fff'
                },
                width : '1040px',
                padding : '0',
                margin : '16px auto'
            };
        },

        getDefaultData : function(){
            return {
                "type_$$comment" : 'u1为1个月的U新标,u3期限3个月的U新标',
                type : 'u1',
                "iconImageUrl_$$comment" : 'icon图片地址',
                iconImageURL : '//www.we.com/cms/5864b3f0c5ee7210913f6796/register/place-holder-img/newer-icon.png',
                "explain_$$comment" : '新手标Title旁边的说明文案',
                explain : '*甄选精品限量发布 新人仅可购买一次',
                "target_$$comment" : '按钮下方的标签文案',
                target : '精选短期 收益更佳'
            };
        },

        init : function(){
            //当前Ajax请求的ID
            this.querySign = null;
            //是否已经绑定了组件自定义事件
            this.eventBinded = false;
            //交易所列表对应的详细数据
            this.listDetailData = null;
        },

        render : function(){
            let cssClass = this.getBaseCssClass() + '  ';
            let cssStyle = this.translateStyle( this.style );
            let $el = $(tpl).addClass( cssClass ).css( cssStyle );
            let $content = $('.glpb-newer-own-list', $el);

            this.$el = $el;
            this.$content = $content;

            if( ! this.isProductionMode() ){
                //编辑模式, 显示一个图片占位
                $(`<li><img class="editor-place-holder-img" src="${editorPlaceHolderImage}" title="新手专享占位图片(非真实数据)" /></li>`).appendTo( $content );
            }
        },

        bindComponentEvent : function(){
            let that = this;
            let data = this.data || {};
            let type = data.type;

            if( this.isProductionMode() && ! this.eventBinded ){
                //正式环境才绑定事件, 并且Ajax请求U计划的具体数据

                let reqData = {
                    type : type
                };
                lpService.getNewer( reqData )
                    .then( ( reqResult ) => {
                        if( reqResult.requestStatus === lpService.STATUS.SUCCESS ){
                            let result = reqResult.data;
                            if( result.status === 0 ){
                                that.setNewerOwnData( result.data.list );
                                return;
                            }
                            return Promise.reject(new Error(result.message));
                        }
                        return Promise.reject( new Error('获取新手专享数据异常!'));
                    })
                    .catch( (e) => {
                        alert(e.message);
                        that.hide();
                    });
            }
        },

        componentWillUnmount : function(){
            this.$content = null;
        },

        setNewerOwnData : function( list ){
            list = list || [];
            if( ! list || list.length < 1 ){
                return this.hide();
            }

            let html = this._renderNewnerOwnItem( list[0] );

            if( html ){
                this.$content.html( html );
            }else{
                this.hide();
            }
        },

        _renderNewnerOwnItem : function( obj ){
            let getHost = utils.getTplConf();
            let hostName = getHost.we_renrendai_host;
            let data = this.data || {};
            let rate = obj.expectedYearRate;
            let time = obj.lockPeriod;
            let name = obj.name;

            let detailURL = `${hostName}/uplan-${obj.id}.html`;

            return `<li class="newer-own-detail clearfix">
                        <div class="newer-title clearfix">
                            <div class="newer-icon">
                                <img src="${data.iconImageURL}" width="100%" />
                            </div>
                            <div class="newer-plan-name">${name}</div>
                            <div class="newer-explain">${data.explain}</div>
                        </div>
                        <dl class="newer-data clearfix">
                            <dt class="clearfix">
                                <div>
                                    <p class="color-deep-orange font-18"><span class="bigger font-36">${rate}</span>%</p>
                                    <p class="tips font-12">扣费后年利率</p>
                                </div>
                    
                                <div>
                                    <p class="color-grey font-18"><span class="bigger font-36">${time}</span>个月</p>
                                    <p class="tips font-12">投资起点</p>
                                </div>
                            </dt>
                            <dd>
                                <a class="btn-join" href="#lp-depository" title="立即加入">立即加入</a>
                                <p>${data.target}</p>
                            </dd>
                        </dl>
                    </li>`;
        }
    }
);


module.exports = NewerOwnItemList;