/**
 * rrd 累计服务用户数、累积成交额组件
 * Created by liucong，2017-6-24
 **/

const moment = require('moment');

const numeral = require('numeral');

const glpbCommon = require('glpb-components-common');

const serviceFactory = require('../../service/service-factory.js');

require('./rrd-lp-company-info.scss');

const BaseComponent = glpbCommon.BaseComponent;

const $ = BaseComponent.$;

const utils = BaseComponent.utils;

const uPlanService = serviceFactory.getService('uPlan');

const tpl = `<div><div class="glpb-rrd-company-info"></div></div>`;

const editorPlaceHolderImage = '//www.we.com/cms/5864b0d6a24d131067ef7956/spread/company_info.jpg?t=1';

const RRDUPlanItem = BaseComponent.extend(
    {
        componentName : 'glpb_rrd_com_pc_company_info',
        componentNameZh : '公司成交额等数据',
        componentCategory : BaseComponent.CATEGORY.UI,
        platform : BaseComponent.PLATFORM.PC,
        canBeChildOfComponentName : function(){
            return true;
        }
    },
    {
        getDefaultStyle : function(){
            return {
                background : {
                    backgroundColor : '#fff'
                },
                width : '100%',
                padding : '0',
                margin : '0 auto'
            };
        },

        getDefaultData : function(){
            return {
            };
        },

        init : function(){
            //当前Ajax请求的ID
            this.querySign = null;
            //是否已经绑定了组件自定义事件
            this.eventBinded = false;
            //产品对应的详细数据
            this.companyInfo = null;
        },

        render : function(){
            let cssClass = this.getBaseCssClass() + '  ';
            let cssStyle = this.translateStyle( this.style );
            let $el = $(tpl).addClass( cssClass ).css( cssStyle );
            let $content = $('.glpb-rrd-company-info', $el);

            this.$el = $el;
            this.$content = $content;

            if( ! this.isProductionMode() ){
                //编辑模式, 显示一个图片占位
                $(`<li><img class="editor-place-holder-img" src="${editorPlaceHolderImage}" title="公司数据占位图(非真实数据)" /></li>`).appendTo( $content );
            }
        },

        bindComponentEvent : function(){
            let that = this;
            let data = this.data || {};
            if( this.isProductionMode() && ! this.eventBinded ){
                //正式环境才绑定事件, 并且Ajax请求U计划的具体数据

                this.querySign = utils.generateQuerySign();
                let reqData = {};

                uPlanService.getCompanyInfo( reqData )
                    .then( ( reqResult ) => {
                        if( reqResult.requestStatus === uPlanService.STATUS.SUCCESS ){
                            let result = reqResult.data;
                            if( result.status === 0 ){
                                let html = this._renderInfoItem( result.data );;
                                that.$content.html( html );
                                return;
                            }
                            return Promise.reject(new Error(result.message));
                        }
                        return Promise.reject( new Error('获取定义产品数据异常!'));
                    })
                    .catch( (e) => {
                        alert(e.message);
                        that.hide();
                    });
            }
        },

        componentWillUnmount : function(){
            this.$content = null;
        },

        handleNumber(num,unit){
            let real_num = num / unit;

            if(real_num >= 1){
                real_num = parseInt( real_num );
            }else if(real_num >= 0){
                real_num = real_num.toFixed(1);
            }else{
                real_num = 0;
            }

            let real_num_arr = ('' + real_num).split("");

            let real_num_arr_html = "<em>" + real_num_arr.join("</em><em>") + "</em>";

            return real_num_arr_html;
        },

        _renderInfoItem : function( obj ){

            let register_num_html = this.handleNumber(obj.userTotalCount,10000);
            let deal_money_html = this.handleNumber(obj.tradeAmount,100000000);

            return `
                <div class="rrd-company-info-box">
                    <div class="data-box">
                        <div class="rrd-data left border-right">累计注册用户数超 <span class="number-box">${register_num_html}万</span></div>
                        <div class="rrd-data right">累计成交额超 <span class="number-box">${deal_money_html}亿</span></div>
                    </div>
                </div>
            `;
        }
    }
);


module.exports = RRDUPlanItem;