/**
 * 优选计划、U计划
 * Created by liucong，2017-6-24
 **/

const moment = require('moment');

const numeral = require('numeral');

const glpbCommon = require('glpb-components-common');

const serviceFactory = require('../../service/service-factory.js');

require('./rrd-lp-u-plan.scss');

const BaseComponent = glpbCommon.BaseComponent;

const $ = BaseComponent.$;

const utils = BaseComponent.utils;

const uPlanService = serviceFactory.getService('uPlan');

const tpl = `<div><div class="glpb-rrd-finance-plan"></div></div>`;

const editorPlaceHolderImage = '//www.we.com/cms/5864b0d6a24d131067ef7956/spread/financePlan.jpg?t=1';


const RRDUPlanItem = BaseComponent.extend(
    {
        componentName : 'glpb_rrd_com_pc_uPlan_item',
        componentNameZh : '新手、优选产品（20170624新样式）',
        componentCategory : BaseComponent.CATEGORY.UI,
        platform : BaseComponent.PLATFORM.PC,
        canBeChildOfComponentName : function(){
            return true;
        }
    },
    {
        getDefaultStyle : function(){
            return {
                background : {
                    backgroundColor : '#fff'
                },
                width : '1080px',
                padding : '0',
                margin : '16px auto'
            };
        },

        getDefaultData : function(){
            return {
                "financePlanType_$$comment" : "输入要显示的U计划产品信息，e.g. 'PREMIUM'、'NOVICE'",
                financePlanType : 'PREMIUM',
                "prductTitle_$$comment" : "产品标题，e.g. 优选计划、U享（支持html写法）",
                prductTitle : '优选',
                "productAd_$$comment" : "广告语，e.g.最高返现1.8%（支持html写法）",
                prductAd : '',
                "productIntro_$$comment": "产品描述语,e.g. 到期后转入自由期，仍享#rate#（支持html写法）",
                productIntro: "使用红包，收益更高",
                "productIntroStyle_$$comment":"产品描述语,e.g. 到期后转入自由期，仍享9.2% 这个话的样式颜色",
                productIntroStyle:"",
                "productButtonStyle_$$comment":"立即加入按钮的样式",
                productButtonStyle : "",
                "prductRateStyle_$$comment":"产品利率的颜色字号样式 如：color:red;font-size:12px",
                prductRateStyle : '',
                "prductMonthStyle_$$comment":"产品月份.起投金额的颜色字号样式 如：color:red;font-size:12px",
                prductMonthStyle : '',
                "prductTextStyle_$$comment":"产品预期年化率.期限.起投金额的颜色字号样式 如：color:red;font-size:12px",
                prductTextStyle : '',
                "rateTipText_$$comment" : "扣费后年利率 文案",
                rateTipText : "扣费后年利率",
            };
        },

        init : function(){
            //当前Ajax请求的ID
            this.querySign = null;
            //是否已经绑定了组件自定义事件
            this.eventBinded = false;
            //产品对应的详细数据
            this.productData = null;
        },

        render : function(){
            let cssClass = this.getBaseCssClass() + '  ';
            let cssStyle = this.translateStyle( this.style );
            let $el = $(tpl).addClass( cssClass ).css( cssStyle );
            let $content = $('.glpb-rrd-finance-plan', $el);

            this.$el = $el;
            this.$content = $content;

            if( ! this.isProductionMode() ){
                //编辑模式, 显示一个图片占位
                $(`<li><img class="editor-place-holder-img" src="${editorPlaceHolderImage}" title="U计划列表占位图片(非真实数据)" /></li>`).appendTo( $content );
            }
        },

        bindComponentEvent : function(){
            let that = this;
            let data = this.data || {};
            let financePlanType = data.financePlanType || [];
            if( this.isProductionMode() && ! this.eventBinded && financePlanType != "" ){
                //正式环境才绑定事件, 并且Ajax请求U计划的具体数据

                this.querySign = utils.generateQuerySign();
                let reqData = {
                    financePlanType : financePlanType
                };

                uPlanService.getFinancePlanListForIndex( reqData )
                    .then( ( reqResult ) => {
                        if( reqResult.requestStatus === uPlanService.STATUS.SUCCESS ){
                            let result = reqResult.data;
                            if( result.status === 0 ){
                                that.setListDetailData( result.data );
                                return;
                            }
                            return Promise.reject(new Error(result.message));
                        }
                        return Promise.reject( new Error('获取定义产品数据异常!'));
                    })
                    .catch( (e) => {
                        alert(e.message);
                        that.hide();
                    });
            }
        },

        componentWillUnmount : function(){
            this.$content = null;
        },

        setListDetailData : function( list ){
            list = list.list || [];
            if( ! list || list.length < 1 ){
                return this.hide();
            }

            let html = '';
            //只展示一条数据
            html += this._renderUPlanItem( list[0] );

            if( html ){
                this.$content.html( html );
            }else{
                this.hide();
            }
        },

        _renderUPlanItem : function( obj ){
            let data = this.data || {};
            let financePlanType = data.financePlanType || [];
            let periodDom = '服务期限';
            if('PREMIUM' == financePlanType){
                periodDom = '固定服务期限';
            }

            let getHost = utils.getTplConf();
            let hostName = getHost.we_renrendai_host;

            let detailURL = `${hostName}/uplan-${obj.id}.html`;

            let productIntro = this.data.productIntro.replace(/#rate#/g,`${obj.expectedYearRate}`);

            //利率
            let baseInterestRate = parseFloat(obj.baseInterestRate || 0).toFixed(1);
            //加息的利率
            let extraInterestRate = parseFloat(obj.extraInterestRate || 0).toFixed(1);
            //如果加息要展示的 加息利率文字
            let increaseRate = '';
            if(extraInterestRate && extraInterestRate !='0.0'){
                increaseRate = '+' + extraInterestRate + '%';
            }

            //颜色字体 样式
            let cmsData = this.data;
            let prductRateStyle = cmsData.prductRateStyle ;
            let prductMonthStyle = cmsData.prductMonthStyle ;
            let prductTextStyle = cmsData.prductTextStyle ;
            let productIntroStyle = cmsData.productIntroStyle;
            let productButtonStyle = cmsData.productButtonStyle;
            let rateTipText = cmsData.rateTipText;
            //prductTextStyle = "fontSize:19px;color:red";
            return `
                <div class="uplan-item-box">
                    <div class="product-title">
                        <div class="fl-right gift">
                            ${this.data.prductAd}
                        </div>
                        <h2>
                            ${this.data.prductTitle}
                        </h2>
                    </div>
                    
                    <ul class="plan-detail-box">
                        <li class="rate-box"><em class="num" style="${prductRateStyle}">${baseInterestRate}</em><em class="symbol" style="${prductRateStyle}">%</em><span class="increase-rate" style="${prductRateStyle}">${increaseRate}</span><span class="plan-rate-text"style="${prductTextStyle}">${ rateTipText || '扣费后年利率'}</span></li>
                        <li class="month-box"><em class="month" style="${prductMonthStyle}">${obj.lockPeriod}个月</em><span class="plan-rate-text" style="${prductTextStyle}">${periodDom}</span></li>
                        <li class="money-num-box"><em class="money-num" style="${prductMonthStyle}">${obj.minRegisterAmount}元</em><span class="plan-rate-text" style="${prductTextStyle}">最低授权出借本金</span></li>
                        <li class="tip-box"><a class="join-btn" href="#lp-depository" style="${productButtonStyle}">授权出借</a><span class="plan-desc" style="${productIntroStyle}">${productIntro}</span></li>
                    </ul>
                </div>
            `;
        }
    }
);


module.exports = RRDUPlanItem;
