/**
 * 优选计划组件
 * Created by liling，2017/6/1
 **/

const moment = require('moment');

const numeral = require('numeral');

const glpbCommon = require('glpb-components-common');

const serviceFactory = require('../../service/service-factory.js');

require('./uplan-premium.scss');

const BaseComponent = glpbCommon.BaseComponent;

const $ = BaseComponent.$;

const utils = BaseComponent.utils;

const uPlanService = serviceFactory.getService('uPlan');

const tpl = "<div><div class='glpb-pc-uplan-premium'></div></div>";

const editorPlaceHolderImage = '//www.we.com/cms/5864b3f0c5ee7210913f6796/uplan_premium/uplan-premium.jpg';

const UplanPremiumItem = BaseComponent.extend(
    {
        componentName : 'glpb_we_com_pc_uplan_premium',
        componentNameZh : 'PC-优选计划',
        componentCategory : BaseComponent.CATEGORY.UI,
        platform : BaseComponent.PLATFORM.PC,
        canBeChildOfComponentName : function(){
            return true;
        }
    },
    {
        getDefaultStyle : function(){
            return {
                background : {
                    backgroundColor : '#f2f2f2'
                },
                width : 'auto',
                padding : '0',
                margin : '16px auto'
            };
        },

        getDefaultData : function(){
            return {
                "style_$$comment" : 'warm为暖色调,cold为冷色调',
                style: 'warm'

            };
        },

        init : function(){
            //当前Ajax请求的ID
            this.querySign = null;
            //是否已经绑定了组件自定义事件
            this.eventBinded = false;
            //交易所列表对应的详细数据
            this.listDetailData = null;
        },

        render : function(){
            let cssClass = this.getBaseCssClass() + ' ';
            let cssStyle = this.translateStyle( this.style );
            let $el = $(tpl).addClass( cssClass ).css( cssStyle );
            let $content = $('.glpb-pc-uplan-premium', $el);
            this.$el = $el;
            this.$content = $content;

            if( ! this.isProductionMode() ){
                //编辑模式, 显示一个图片占位
                $(`<li><img class="editor-place-holder-img" src="${editorPlaceHolderImage}" title="U计划列表占位图片(非真实数据)" /></li>`).appendTo( $content );
            }
        },

        bindComponentEvent : function(){
            let that = this;
            let data = this.data || {};
            if( this.isProductionMode() && ! this.eventBinded){
                //正式环境才绑定事件, 并且Ajax请求U计划的具体数据
                this.querySign = utils.generateQuerySign();

                uPlanService.getUplanPremium()
                     .then( (reqResult) =>{
                         if( reqResult.requestStatus === uPlanService.STATUS.SUCCESS ){
                             let result = reqResult.data;
                             if( result.status === 0 ){
                                that.setListDetailData( result.data.list );
                                 return;
                             }
                             return Promise.reject( new Error(result.message) );
                         }
                         return Promise.reject( new Error('获取优选数据异常!') );
                     })
                     .catch( (e) => {
                         alert( e.message );
                         that.hide();
                });

            }

        },

        componentWillUnmount : function(){
            this.$content = null;
        },

        setListDetailData : function(list){
            list = list || []
            if( !list && list.length < 1 ){
                return this.hide();
            }

            let html ='';
            //取数组第一条数据
            html = this._renderUPlanPremium(list[0]);
            this.$content.html(html);
        },

        _renderUPlanPremium : function(obj){

            return `<ul class="premuim-list">
                        <li class="premuim-name">优选计划</li>
                        <li class="premuim-rate">
                            <p>${obj.expectedYearRate}<span>%</span></p>
                            <p class="text">扣费后年利率</p>
                        </li>
                        <li class="premuim-lock">
                            <p>到期后仍享${obj.expectedYearRate}%  随时可退</p>
                            <p class="text">${obj.lockPeriod}个月锁定期</p>
                        </li>
                        <li class="premuim-btn"><a class="btn-join" href="#lp-depository">立即加入</a></li>
                    </ul>`;
        }
    }
);


module.exports = UplanPremiumItem;